@@ -1,10 +1,13 @@
 import os
 
+from . import __meta__
 from .app import App
 from .routes.decorator import route
 from .routes.parameter_interface import IParam
 from .routes.validator import Validator
 
+__version__ = __meta__.version
+
 val = Validator
 """
 Validator 的简短别名
@@ -26,5 +29,6 @@ __all__ = [
     'route',
     'val',
     'IParam',
-    'env'
+    'env',
+    '__version__'
 ]
